
.zoomable{
  cursor: pointer;
}
.zoomable:fullscreen {
  width: 100%;
  display: grid;
  grid-template-rows: auto;
}
.zoomable:fullscreen img {
  margin: 0;
  position: fixed;
  top: 0;
  width: 100%;
  height: 100%;
  min-width: 0;
  max-width: none;
  min-height: 0;
  max-height: none;
  box-sizing: border-box;
  object-fit: contain;
  transform: none;
}
.zoomable:fullscreen figcaption{
  color: white;
  width: 100%;
  display: block;
  position: fixed;
  bottom: 0;
  padding: 0.5em max(50% - 380px, 1em);
  font-size: 1.2em;
  text-align: center;
  background-color: rgba(0, 0, 0, 0.377);
}
